@@ -1,6 +1,6 @@
 import requests
 from requests import Response
-from typing import Dict, List, Optional
+from typing import Dict, List, Optional, Union
 from xml.etree import ElementTree
 from copy import copy
 from time import time, sleep
@@ -12,6 +12,13 @@ from .queries import (
 )
 
 
+def _match_all(**kwargs):
+    return ' AND '.join([
+        f'{value}[{field}]'
+        for field, value in kwargs.items()
+    ])
+
+
 class EntrezResponse:
     """The wrapper around the Entrez response."""
 
@@ -119,9 +126,12 @@ class EntrezAPI:
     # TODO: make entrez response a generic and provide better typing of responses
     @uses_query(SearchQuery)
     def search(
-        self, term: str, max_results: int,
+        self, term: Union[str, dict], max_results: int,
         database: EntrezDatabase = 'pubmed', min_date=None, max_date=None
     ):
+        if isinstance(term, dict):
+            term = _match_all(**term)
+
         assert not min_date and not max_date  # TODO
         query = SearchQuery(term=term, max_results=max_results, database=database)
         return self._request(query=query)
@@ -138,6 +148,7 @@ class EntrezAPI:
         self, ids: List[str], max_results: int,
         database: EntrezDatabase = 'pubmed'
     ):
+        self._ensure_list_like(ids)
         query = SummaryQuery(ids=ids, max_results=max_results, database=database)
         return self._request(query=query)
 
@@ -147,6 +158,7 @@ class EntrezAPI:
         self, ids: List[str], max_results: int,
         database: EntrezDatabase = 'pubmed', return_type: ReturnType = 'xml'
     ):
+        self._ensure_list_like(ids)
         query = FetchQuery(ids=ids, max_results=max_results, database=database, return_type=return_type)
         return self._request(query=query)
 
@@ -161,6 +173,7 @@ class EntrezAPI:
         # optional
         command: CommandType = 'neighbor'
     ):
+        self._ensure_list_like(ids)
         query = LinkQuery(
             ids=ids, database=database, database_from=database_from,
             command=command
@@ -176,3 +189,16 @@ class EntrezAPI:
     def find_citations(self, citations: List[Citation], database='pubmed'):
         query = CitationQuery(database=database, citations=citations)
         return self._request(query=query)
+
+    @staticmethod
+    def _ensure_list_like(ids: List[str]):
+        """Protect user from accidentally passing and ID, say `'142'` instead of a list,
+
+        like `['142']` as the former would actually be interpreted as three queries,
+        equivalent to: `['1', '2', '3']`.
+        """
+        for atomic_iterable_type in [str, bytes]:
+            if isinstance(ids, atomic_iterable_type):
+                raise ValueError(
+                    f'Received {atomic_iterable_type.__name__} but a list-like container of identifiers was expected'
+                )
